@@ -194,23 +194,19 @@
 #define __NR_vfork                  189
 #define __NR_ugetrlimit             190
 #define __NR_readahead              191
-#if !defined(__PPC64) || defined(__ABI32)
 #define __NR_mmap2                  192
 #define __NR_truncate64             193
 #define __NR_ftruncate64            194
 #define __NR_stat64                 195
 #define __NR_lstat64                196
 #define __NR_fstat64                197
-#endif
 #define __NR_pciconfig_read         198
 #define __NR_pciconfig_write        199
 #define __NR_pciconfig_iobase       200
 #define __NR_multiplexer            201
 #define __NR_getdents64             202
 #define __NR_pivot_root             203
-#if !defined(__PPC64) || defined(__ABI32)
 #define __NR_fcntl64                204
-#endif
 #define __NR_madvise                205
 #define __NR_mincore                206
 #define __NR_gettid                 207
@@ -231,9 +227,7 @@
 #define __NR_sched_setaffinity      222
 #define __NR_sched_getaffinity      223
 #define __NR_tuxcall                225
-#if !defined(__PPC64) || defined(__ABI32)
 #define __NR_sendfile64             226
-#endif
 #define __NR_io_setup               227
 #define __NR_io_destroy             228
 #define __NR_io_getevents           229
@@ -261,9 +255,7 @@
 #define __NR_utimes                 251
 #define __NR_statfs64               252
 #define __NR_fstatfs64              253
-#if !defined(__PPC64) || defined(__ABI32)
 #define __NR_fadvise64_64           254
-#endif
 #define __NR_rtas		255
 #define __NR_sys_debug_setcontext 256
 #define __NR_migrate_pages	258
@@ -299,11 +291,7 @@
 #define __NR_mknodat		288
 #define __NR_fchownat		289
 #define __NR_futimesat		290
-#if defined(__PPC64) && !defined(__ABI32)
-#define __NR_newfstatat		291
-#else
 #define __NR_fstatat64		291
-#endif
 #define __NR_unlinkat		292
 #define __NR_renameat		293
 #define __NR_linkat		294
@@ -376,6 +364,10 @@
 #define __NR_memfd_create          360
 #define __NR_bpf                   361
 #define __NR_execveat              362
+#define __NR_switch_endian         363
+#define __NR_userfaultfd           364
+#define __NR_membarrier            365
+#define __NR_mlock2                378
 
 /*
  * repeated with SYS prefix
@@ -576,23 +568,19 @@
 #define SYS_vfork                  189
 #define SYS_ugetrlimit             190
 #define SYS_readahead              191
-#if !defined(__PPC64) || defined(__ABI32)
 #define SYS_mmap2                  192
 #define SYS_truncate64             193
 #define SYS_ftruncate64            194
 #define SYS_stat64                 195
 #define SYS_lstat64                196
 #define SYS_fstat64                197
-#endif
 #define SYS_pciconfig_read         198
 #define SYS_pciconfig_write        199
 #define SYS_pciconfig_iobase       200
 #define SYS_multiplexer            201
 #define SYS_getdents64             202
 #define SYS_pivot_root             203
-#if !defined(__PPC64) || defined(__ABI32)
 #define SYS_fcntl64                204
-#endif
 #define SYS_madvise                205
 #define SYS_mincore                206
 #define SYS_gettid                 207
@@ -613,9 +601,7 @@
 #define SYS_sched_setaffinity      222
 #define SYS_sched_getaffinity      223
 #define SYS_tuxcall                225
-#if !defined(__PPC64) || defined(__ABI32)
 #define SYS_sendfile64             226
-#endif
 #define SYS_io_setup               227
 #define SYS_io_destroy             228
 #define SYS_io_getevents           229
@@ -643,9 +629,7 @@
 #define SYS_utimes                 251
 #define SYS_statfs64               252
 #define SYS_fstatfs64              253
-#if !defined(__PPC64) || defined(__ABI32)
 #define SYS_fadvise64_64           254
-#endif
 #define SYS_rtas		255
 #define SYS_sys_debug_setcontext 256
 #define SYS_migrate_pages	258
@@ -681,11 +665,7 @@
 #define SYS_mknodat		288
 #define SYS_fchownat		289
 #define SYS_futimesat		290
-#if defined(__PPC64) && !defined(__ABI32)
-#define SYS_newfstatat		291
-#else
 #define SYS_fstatat64		291
-#endif
 #define SYS_unlinkat		292
 #define SYS_renameat		293
 #define SYS_linkat		294
@@ -758,3 +738,7 @@
 #define SYS_memfd_create          360
 #define SYS_bpf                   361
 #define SYS_execveat              362
+#define SYS_switch_endian         363
+#define SYS_userfaultfd           364
+#define SYS_membarrier            365
+#define SYS_mlock2                378
